# Security Policy

## Supported Versions

The latest versions of pythonbible are supported.

You are encouraged to write tests for your application and update your pythonbible version frequently after ensuring that your tests are passing. This way you will benefit from the latest features, bug fixes, and **security fixes**.

| Version   | Supported          |
| --------- | ------------------ |
|   0.5.x   | :white_check_mark: |
| < 0.5.0   | :x:                |


## Reporting a Vulnerability

If you think you found a vulnerability, and even if you are not sure about it, please report it right away by sending an email to: npatton@gmail.com. Please try to be as explicit as possible, describing all the steps and example code to reproduce the security issue.

I will review it thoroughly and get back to you.

## Public Discussions

Please restrain from publicly discussing a potential security vulnerability.

It's better to discuss privately and try to find a solution first, to limit the potential impact as much as possible.

---

Thanks for your help!
